<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.UI

Windows Runtime (WinRT) APIs for for the `Windows.UI` namespace.

This package provides the `winrt.windows.ui` module.
